==> hapi-fhir-structures-r4-3.3.0-sources.jar: org/hl7/fhir/r4/model/codesystems/UsersessionStatus.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sat, Mar 3, 2018 18:00-0500 for FHIR v3.2.0


import org.hl7.fhir.exceptions.FHIRException;

public enum UsersessionStatus {

        /**
         * The user session is activating
         */
        ACTIVATING, 
        /**
         * The user session is active
         */
        ACTIVE, 
        /**
         * The user session is suspended
         */
        SUSPENDED, 
        /**
         * The user session is closing
         */
        CLOSING, 
        /**
         * The user session is closed
         */
        CLOSED, 
        /**
         * added to help the parsers
         */
        NULL;
        public static UsersessionStatus fromCode(String codeString) throws FHIRException {
            if (codeString == null || "".equals(codeString))
                return null;
        if ("activating".equals(codeString))
          return ACTIVATING;
        if ("active".equals(codeString))
          return ACTIVE;
        if ("suspended".equals(codeString))
          return SUSPENDED;
        if ("closing".equals(codeString))
          return CLOSING;
        if ("closed".equals(codeString))
          return CLOSED;
        throw new FHIRException("Unknown UsersessionStatus code '"+codeString+"'");
        }
        public String toCode() {
          switch (this) {
            case ACTIVATING: return "activating";
            case ACTIVE: return "active";
            case SUSPENDED: return "suspended";
            case CLOSING: return "closing";
            case CLOSED: return "closed";
            default: return "?";
          }
        }
        public String getSystem() {
          return "http://hl7.org/fhir/usersession-status";
        }
        public String getDefinition() {
          switch (this) {
            case ACTIVATING: return "The user session is activating";
            case ACTIVE: return "The user session is active";
            case SUSPENDED: return "The user session is suspended";
            case CLOSING: return "The user session is closing";
            case CLOSED: return "The user session is closed";
            default: return "?";
          }
        }
        public String getDisplay() {
          switch (this) {
            case ACTIVATING: return "Activating";
            case ACTIVE: return "Active";
            case SUSPENDED: return "Suspending";
            case CLOSING: return "Closing";
            case CLOSED: return "Closed";
            default: return "?";
          }
    }


}

==> hapi-fhir-structures-r4-3.4.0-sources.jar: org/hl7/fhir/r4/model/codesystems/UsersessionStatus.java <==
package org.hl7.fhir.r4.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sun, May 6, 2018 17:51-0400 for FHIR v3.4.0


import org.hl7.fhir.exceptions.FHIRException;

public enum UsersessionStatus {

        /**
         * The user session is activating
         */
        ACTIVATING, 
        /**
         * The user session is active
         */
        ACTIVE, 
        /**
         * The user session is suspended
         */
        SUSPENDED, 
        /**
         * The user session is closing
         */
        CLOSING, 
        /**
         * The user session is closed
         */
        CLOSED, 
        /**
         * added to help the parsers
         */
        NULL;
        public static UsersessionStatus fromCode(String codeString) throws FHIRException {
            if (codeString == null || "".equals(codeString))
                return null;
        if ("activating".equals(codeString))
          return ACTIVATING;
        if ("active".equals(codeString))
          return ACTIVE;
        if ("suspended".equals(codeString))
          return SUSPENDED;
        if ("closing".equals(codeString))
          return CLOSING;
        if ("closed".equals(codeString))
          return CLOSED;
        throw new FHIRException("Unknown UsersessionStatus code '"+codeString+"'");
        }
        public String toCode() {
          switch (this) {
            case ACTIVATING: return "activating";
            case ACTIVE: return "active";
            case SUSPENDED: return "suspended";
            case CLOSING: return "closing";
            case CLOSED: return "closed";
            default: return "?";
          }
        }
        public String getSystem() {
          return "http://hl7.org/fhir/usersession-status";
        }
        public String getDefinition() {
          switch (this) {
            case ACTIVATING: return "The user session is activating";
            case ACTIVE: return "The user session is active";
            case SUSPENDED: return "The user session is suspended";
            case CLOSING: return "The user session is closing";
            case CLOSED: return "The user session is closed";
            default: return "?";
          }
        }
        public String getDisplay() {
          switch (this) {
            case ACTIVATING: return "Activating";
            case ACTIVE: return "Active";
            case SUSPENDED: return "Suspending";
            case CLOSING: return "Closing";
            case CLOSED: return "Closed";
            default: return "?";
          }
    }


}
